==> asksuite-core-2.28.1.tgz: package/services/ExactMatcherAccessor.js <==
const { CacheRedis } = require('../util/CacheRedis');
const md5 = require('md5');
const AsksuiteProcessingNaturalUtils = require('../AsksuiteProcessingNaturalUtils');
const AsksuiteTranslator = require('../util/Translator');

class ExactMatcherAccessor {
  constructor(config) {
    this.config = config.config;
    this.client = config.redis;
    this.caches = {};
    this.utils = new AsksuiteProcessingNaturalUtils();

    this.caches = new CacheRedis({
      client: this.client,
      prefixKey: `exact_matcher`,
      expirationTime: 0,
      isJson: false,
    });
  }

  async resolveText(request) {
    const { companyId, language: requestLanguage, languages, defaultLanguage } = request;
    const language = this.utils.resolveLanguage(requestLanguage, languages);
    let { text } = request;

    if (language !== defaultLanguage) {
      const asksuiteTranslator = new AsksuiteTranslator(
        this.config.INFOCHAT_DATA_SERVER,
        this.config.GOOGLE_TRANSLATE_KEY,
      );

      const translation = await asksuiteTranslator.googleTranslateIfNeeded(
        text,
        language,
        languages,
        defaultLanguage,
      );

      text = translation.translation;
    }

    const textHash = md5(this.normalizeText(text));
    const key = `${companyId}:${defaultLanguage}:${textHash}`;

    const intentFound = await this.caches.get(key);
    const dialogFound = this.utils.findDialogByIntent(request, intentFound);
    let dialog = '';
    if (dialogFound && dialogFound.dialog) {
      dialog = dialogFound.dialog;
    }

    return {
      intent: intentFound || 'naoentendi',
      dialog,
      fromCache: true,
      extractedData: null,
    };
  }

  normalizeText(text) {
    try {
      return text
        .trim()
        .replace(/\s\s+/g, ' ')
        .replace(/[.,\/#!$%^&*;:{}=\-_`~()?@]/g, '')
        .normalize('NFD')
        .replace(/[\u0300-\u036f]/g, '')
        .toLowerCase();
    } catch (e) {
      console.error('RedisService.normalizeText', text, e);
      return text;
    }
  }
}

module.exports = ExactMatcherAccessor;

==> asksuite-core-2.28.4.tgz: package/services/ExactMatcherAccessor.js <==
const { CacheRedis } = require('../util/CacheRedis');
const md5 = require('md5');
const AsksuiteProcessingNaturalUtils = require('../AsksuiteProcessingNaturalUtils');
const AsksuiteTranslator = require('../util/Translator');

class ExactMatcherAccessor {
  constructor(config) {
    this.config = config.config;
    this.client = config.redis;
    this.caches = {};
    this.utils = new AsksuiteProcessingNaturalUtils();

    this.caches = new CacheRedis({
      client: this.client,
      prefixKey: `exact_matcher`,
      expirationTime: 0,
      isJson: false,
    });
  }

  async resolveText(request) {
    const { companyId, language: requestLanguage, languages, defaultLanguage } = request;
    const language = this.utils.resolveLanguage(requestLanguage, languages);
    let { text } = request;

    if (language.substr(0, 2) !== defaultLanguage.substr(0, 2)) {
      const result = await this.resolveText({
        ...request,
        defaultLanguage: language,
      });

      if (result.intent !== 'naoentendi') {
        return result;
      }

      const asksuiteTranslator = new AsksuiteTranslator(
        this.config.INFOCHAT_DATA_SERVER,
        this.config.GOOGLE_TRANSLATE_KEY,
      );

      const translation = await asksuiteTranslator.googleTranslateIfNeeded(
        text,
        language,
        languages,
        defaultLanguage,
      );

      text = translation.translation;
    }

    const textHash = md5(this.normalizeText(text));
    const key = `${companyId}:${defaultLanguage.substr(0, 2)}:${textHash}`;

    const intentFound = await this.caches.get(key);
    const dialogFound = this.utils.findDialogByIntent(request, intentFound);
    let dialog = '';
    if (dialogFound && dialogFound.dialog) {
      dialog = dialogFound.dialog;
    }

    return {
      intent: intentFound || 'naoentendi',
      dialog,
      fromCache: true,
      extractedData: null,
    };
  }

  normalizeText(text) {
    try {
      return text
        .trim()
        .replace(/\s\s+/g, ' ')
        .replace(/[.,\/#!$%^&*;:{}=\-_`~()?@]/g, '')
        .normalize('NFD')
        .replace(/[\u0300-\u036f]/g, '')
        .toLowerCase();
    } catch (e) {
      console.error('RedisService.normalizeText', text, e);
      return text;
    }
  }
}

module.exports = ExactMatcherAccessor;
